
# Slot: domain


defines the type of the subject of the slot.  Given the following slot definition
  S1:
    domain: C1
    range:  C2
the declaration
  X:
    S1: Y

implicitly asserts that X is an instance of C1

URI: [meta:domain](https://w3id.org/biolink/biolinkml/meta/domain)

## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>REQ</sub> [ClassDefinition](ClassDefinition.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
